<?php

/**
 * @file
 * Create blocks for the TabT Matches module.
 */

function _tabt_matches_get_matches_between($datefrom, $dateto, $season = NULL) {
  $season = tabt_process_seasonnumber($season);
  $teams = tabt_get_teams($season);
  $teams = $teams->TeamEntries;
  usort($teams, 'tabt_teams_sort');
  $matches = array();
  foreach ($teams as $team) {
    $matchlist = tabt_matches_get_matches($team->TeamId, $season);
    foreach ($matchlist as $match) {
      $date = DateTime::createFromFormat('Y-m-d H:i:s', $match->Date . ' ' . $match->Time);
      if ($date != NULL) {
        if ($date->getTimestamp() >= $datefrom && $date->getTimestamp() <= $dateto) {
          $matches[$team->TeamId] = $match;
        }
      }
    }
  }
  return $matches;
}

/**
 * Create a block showing the rank for all teams.
 */
function _tabt_matches_rankings_block() {
  $block = array();
  $block['subject'] = t('Rankings');

  $header = array(t('Team'), t('Rank'), t('Points'));
  $rows = array();

  $teams = tabt_get_teams();
  $teams = $teams->TeamEntries;
  usort($teams, 'tabt_teams_sort');
  foreach ($teams as $team) {
    $rank = tabt_matches_get_rank($team->TeamId);
    if (isset($rank->Position) && isset($rank->Points)) {
      $rows[] = array(l(tabt_get_teamname($team->TeamId), variable_get('tabt_matches_rankingpage', 'championship/ranking') . '/' . tabt_get_teamurl($team->TeamId)), $rank->Position, $rank->Points);
    }
  }
  $block['content'] = theme('table', array('header' => $header, 'rows' => $rows));
  return $block;
}

/**
 * Create a block showing the next match of each team.
 */
function _tabt_matches_next_matches_block() {
  $block = array();
  $block['subject'] = t('Next Matches');

  $teams = tabt_get_teams();
  $teams = $teams->TeamEntries;
  usort($teams, 'tabt_teams_sort');
  $matches = array();
  foreach ($teams as $team) {
    $matches[$team->TeamId] = tabt_matches_get_next_match($team->TeamId);
  }
  $block['content'] = theme('tabt_upcoming_matches', array('matches' => $matches));
  return $block;
}

/**
 * Create a block showing the matches of the next divisionweek.
 */
function _tabt_matches_next_divisionweek_matches_block() {
  $block = array();
  $block['subject'] = t('Upcoming Matches');

  $datefrom = tabt_matches_get_next_divisionweek();
  $dateto = strtotime("+1 week", $datefrom);

  $matches = _tabt_matches_get_matches_between($datefrom, $dateto);
  $block['content'] = theme('tabt_upcoming_matches', array('matches' => $matches));
  return $block;
}

/**
 * Create a block showing the matches of the current yearweek.
 */
function _tabt_matches_current_yearweek_matches_block() {
  $block = array();
  $block['subject'] = t('Matches this week');

  $datefrom = strtotime("monday this week", time());
  $dateto = strtotime("+1 week", $datefrom);

  $matches = _tabt_matches_get_matches_between($datefrom, $dateto);

  $block['content'] = theme('tabt_past_matches', array('matches' => $matches));
  return $block;
}

/**
 * Create a block showing the previous match of each team.
 */
function _tabt_matches_previous_matches_block() {
  $block = array();
  $block['subject'] = t('Previous Matches');

  $teams = tabt_get_teams();
  $teams = $teams->TeamEntries;
  usort($teams, 'tabt_teams_sort');
  $matches = array();
  foreach ($teams as $team) {
    $matches[$team->TeamId] = tabt_matches_get_last_match($team->TeamId);
  }

  $block['content'] = theme('tabt_past_matches', array('matches' => $matches));
  return $block;
}

/**
 * Create a block showing the matches of the previous divisionweek.
 */
function _tabt_matches_previous_divisionweek_matches_block() {
  $block = array();
  $block['subject'] = t('Latest Matches');

  $datefrom = tabt_matches_get_previous_divisionweek();
  $dateto = strtotime("+1 week", $datefrom);

  $matches = _tabt_matches_get_matches_between($datefrom, $dateto);

  $block['content'] = theme('tabt_past_matches', array('matches' => $matches));
  return $block;
}

/**
 * Create a block showing the matches of the current yearweek.
 */
function _tabt_matches_previous_yearweek_matches_block() {
  $block = array();
  $block['subject'] = t('Matches last week');

  $dateto = strtotime("monday this week", time());
  $datefrom = strtotime("-1 week", $dateto);

  $matches = _tabt_matches_get_matches_between($datefrom, $dateto);

  $block['content'] = theme('tabt_past_matches', array('matches' => $matches));
  return $block;
}

/**
 * Theme the list of upcoming matches.
 */
function theme_tabt_upcoming_matches($variables) {
  if (variable_get('tabt_locale')) {
    setlocale(LC_ALL, variable_get('tabt_locale'));
  }

  $matches = $variables['matches'];

  $header = array(t('Date'), t('Home'), t('Away'));
  $rows = array();

  foreach ($matches as $team => $match) {
    if (isset($match->AwayTeam)) {
      $date = DateTime::createFromFormat('Y-m-d H:i:s', $match->Date . ' ' . $match->Time);
      if ($date) {
        $datestring = strftime('%a %e/%b, %Hu%M', $date->getTimestamp());
      }
      else {
        $datestring = '';
      }
      $row = array($datestring);
      $match->HomeTeam = check_plain($match->HomeTeam);
      $match->AwayTeam = check_plain($match->AwayTeam);
      $teaminfo = tabt_get_teaminfo($team);
      if ($match->isHome && drupal_strtoupper(drupal_substr($match->HomeTeam, -1)) == drupal_strtoupper($teaminfo->Team)) {
        $match->HomeTeam = array('style' => 'font-weight: bold;', 'data' => l($match->HomeTeam, variable_get('tabt_matches_matchespage', 'championship/calendar') . '/' . tabt_get_teamurl($team)));
      }
      else {
        $match->AwayTeam = array('style' => 'font-weight: bold;', 'data' => l($match->AwayTeam, variable_get('tabt_matches_matchespage', 'championship/calendar') . '/' . tabt_get_teamurl($team)));
      }
      array_push($row, $match->HomeTeam, $match->AwayTeam);
      $rows[] = $row;
    }
    else {
      $rows[] = array('', array('style' => 'font-weight: bold;', 'data' => l(tabt_get_teamname($team), variable_get('tabt_matches_matchespage', 'championship/calendar') . '/' . tabt_get_teamurl($team))), '');
    }
  }
  return theme('table', array('header' => $header, 'rows' => $rows, 'empty' => t('No matches scheduled.')));

}

/**
 * Theme the list of past matches.
 */
function theme_tabt_past_matches($variables) {
  if (variable_get('tabt_locale')) {
    setlocale(LC_ALL, variable_get('tabt_locale'));
  }

  $matches = $variables['matches'];

  $header = array(t('Date'), t('Home'), t('Away'), t('Score'));
  $rows = array();

  foreach ($matches as $team => $match) {
    if (isset($match->AwayTeam)) {
      $date = DateTime::createFromFormat('Y-m-d H:i:s', $match->Date . ' ' . $match->Time);
      if ($date) {
        $datestring = strftime('%a %e/%b', $date->getTimestamp());
      }
      else {
        $datestring = '';
      }
      $row = array($datestring);
      $homestyle = '';
      $awaystyle = '';
      if ($match->Withdrawal == 0 || $match->Withdrawal == 2) {
        $homestyle = 'text-decoration: line-through; ';
      }
      elseif ($match->Withdrawal == 1 || $match->Withdrawal == 2) {
        $awaystyle = 'text-decoration: line-through; ';
      }
      $match->HomeTeam = check_plain($match->HomeTeam);
      $match->AwayTeam = check_plain($match->AwayTeam);
      $teaminfo = tabt_get_teaminfo($team);
      if ($match->isHome && drupal_strtoupper(drupal_substr($match->HomeTeam, -1)) == drupal_strtoupper($teaminfo->Team)) {
        $match->HomeTeam = array('style' => $homestyle . 'font-weight: bold;', 'data' => l($match->HomeTeam, variable_get('tabt_matches_rankingpage', 'championship/calendar') . '/' . tabt_get_teamurl($team)));
      }
      else {
        $match->AwayTeam = array('style' => $awaystyle . 'font-weight: bold;', 'data' => l($match->AwayTeam, variable_get('tabt_matches_rankingpage', 'championship/calendar') . '/' . tabt_get_teamurl($team)));
      }
      if (isset($match->Link)) {
        $match->Score = l($match->Score, $match->Link);
      }
      elseif (!isset($match->Score)) {
        $match->Score = '';
      }
      array_push($row, $match->HomeTeam, $match->AwayTeam, $match->Score);
      $rows[] = $row;
    }
  }

  return theme('table', array('header' => $header, 'rows' => $rows, 'empty' => t('No matches played.')));
}