<?php
/**
 * @file
 * Create and theme the calendarpage.
 */

/**
 * Create the calendarpage for a team.
 *
 * This page can be formatted with theme_tabt_matchespage().
 * The rankingarray can be accessed through $matches.
 *
 * @param team
 *   The team to get the calendar for.
 * @param season
 *   The season currently being viewed.
 */
function tabt_matches_matchespage($team, $season = NULL) {
  // We only show the matches for a valid team.
  if (!tabt_is_valid_team(drupal_strtoupper($team), $season)) {
    drupal_not_found();
    return;
  }

  // Get the teaminfo so we can get the division.
  $teaminfo = tabt_get_teaminfo($team, $season);
  if (!$teaminfo) {
    // If we get here, the API screwed up and we didn't get a valid
    // TeamEntry-object.
    drupal_not_found();
    return;
  }
  $season = tabt_process_seasonnumber($season);

  // Set the pagetitle and replace the tokens.
  $title = format_string(variable_get('tabt_matches_matchespage_title', 'Calendar @club @team: @division - @season'),
      array('@club' => variable_get('tabt_club_name', 'Team'), '@team' => tabt_get_teamname($team, $season), '@division' => $teaminfo->DivisionName, '@season' => tabt_get_seasonname($season)));
  drupal_set_title($title);

  // Get all matches
  $matches = tabt_matches_get_matches($team, $season);

  return array(
      '#theme'     => 'tabt_calendar',
      '#matches'   => $matches,
      '#team'      => $team,
      '#teaminfo'  => $teaminfo,
      '#season' => $season
  );
}

/**
 * Theme the calendar.
 */
function theme_tabt_calendar($variables) {
  $output = '';
  $matches = $variables['matches'];
  $team = check_plain($variables['team']);
  $teaminfo = $variables['teaminfo'];
  $teamletter = check_plain($teaminfo->Team);
  if (variable_get('tabt_locale')) {
    setlocale(LC_ALL, variable_get('tabt_locale'));
  }

  if (isset($teaminfo->Alias)) {
    $teamseasons = tabt_get_seasons_teams($teaminfo->Alias);
    $output .= '<center>' . tabt_get_seasons_form($variables['season'], variable_get('tabt_matches_matchespage', 'championship/calendar') . '/' . $teaminfo->Alias, $teamseasons) . '</center>';
  }

  // Loop through received entries of the ranking and prepare
  // the table to be displayed.
  $header = array(t('Week'), t('Date') . ', ' . t('Time'), t('Hometeam'), t('Away'), t('Score'));
  $rows = array();

  foreach ($matches as $match) {
    $date = DateTime::createFromFormat('Y-m-d H:i:s', $match->Date . ' ' . $match->Time);
    if ($date) {
      $datestring = strftime('%a %e/%b, %Hu%M', $date->getTimestamp());
    }
    else {
      $datestring = '';
    }
    $row = array(check_plain($match->WeekName), $datestring);
    $homestyle = '';
    $awaystyle = '';
    if ($match->Withdrawal == 0 || $match->Withdrawal == 2) {
      $homestyle .= 'text-decoration: line-through;';
    }
    elseif ($match->Withdrawal == 1 || $match->Withdrawal == 2) {
      $awaystyle .= 'text-decoration: line-through;';
    }
    if ($match->isHome && drupal_strtoupper(drupal_substr($match->HomeTeam, -1)) == drupal_strtoupper($teamletter)) {
      $homestyle .= 'font-weight: bold;';
    }
    else {
      $awaystyle .= 'font-weight: bold;';
    }
    array_push($row, array('style' => $homestyle, 'data' => check_plain($match->HomeTeam)), array('style' => $awaystyle, 'data' => check_plain($match->AwayTeam)));
    if ($match->Link) {
      $row[] = l($match->Score, $match->Link);
    }
    elseif ($match->Score) {
      $row[] = $match->Score;
    }
    else {
      $row[] = '';
    }
    $rows[] = $row;
  }
  $output .= theme('table', array('header' => $header, 'rows' => $rows));
  $output .= '<small>' . (t('Information obtained from !link', array('!link' => l('http://' . variable_get('tabt_site', 'competitie.vttl.be'), 'http://' . variable_get('tabt_site', 'competitie.vttl.be'))))) . '</small>' . "\n";
  return $output;
}