<?php
/**
 * @file
 * Create and theme the matchpage.
 */

/**
 * Create a matchpage.
 *
 * This page can be formatted with theme_tabt_matchpage().
 * The TabTmatch-object can be accessed through $match.
 *
 * @param id
 *   The id of the match.
 */
function tabt_matches_matchpage($id, $season = NULL) {
  $season = tabt_process_seasonnumber($season);
  // We need the matchnummer, so only allow numeric id's.
  if (!is_numeric($id)) {
    drupal_not_found();
    return;
  }

  // Get the match
  $match = tabt_matches_get_match($id, TRUE, $season);
  // See if there was something wrong with the match (like invalid id)
  // if so, show the Not Found Page.
  if ($match->err) {
    drupal_set_message($match->errinfo);
    drupal_not_found();
    return;
  }

  // Set the pagetitle and replace the tokens.
  $title = format_string(variable_get('tabt_matches_matchpage_title', 'Match: @hometeam - @awayteam'),
      array('@hometeam' => $match->HomeTeam, '@awayteam' => $match->AwayTeam, '@week' => $match->WeekName, '@matchid' => $match->MatchId, '@score' => $match->Score));
  drupal_set_title($title);

  return array(
      '#theme'    => 'tabt_matchpage',
      '#match'    => $match,
  );
}

/**
 * Theme the matchpage.
 */
function theme_tabt_matchpage($variables) {
  $match = $variables['match'];
  $output = '';

  if ($match->Results) {

    if (variable_get('tabt_locale')) {
      setlocale(LC_ALL, variable_get('tabt_locale'));
    }
    $header = array(array('style' => 'width: 15%;', 'data' => t('Match')), array('colspan' => 2, 'style' => 'text-align: right; width: 35%;', 'data' => t('Hometeam')), array('style' => 'width: 35%;', 'colspan' => 2, 'data' => t('Awayteam')), array('style' => 'width: 15%;', 'data' => t('Date') . '/' . t('Time')));
    $row = array(l($match->MatchId, $match->VTTLLink));
    $row[] = array('style' => ($match->isHome ? 'font-weight: bold; ' : '') . ($match->Withdrawal == 0 || $match->Withdrawal == 2 ? 'text-decoration: line-through; ' : '') . 'text-align: right; width: auto;', 'data' => check_plain($match->HomeClub . ' ' . $match->HomeTeam));
    $row[] = array('style' => ($match->isHome ? 'font-weight: bold; ' : '') . 'text-align: right; width: 5%;', 'data' => check_plain($match->HomeScore));
    $row[] = array('style' => ($match->isAway ? 'font-weight: bold; ' : '') . 'width: 5%;', 'data' => check_plain($match->AwayScore));
    $row[] = array('style' => ($match->isAway ? 'font-weight: bold; ' : '') . ($match->Withdrawal == 1 || $match->Withdrawal == 2 ? 'text-decoration: line-through; ' : '') . 'width: auto;', 'data' =>  check_plain($match->AwayClub . ' ' . $match->AwayTeam));
    $datestring = '';
    if ($match->Results) {
      $datetype = 'd-m-y';
    }
    else {
      $datetype = 'y-m-d';
    }
    if ($match->Date) {
      if ($match->Time) {
        $date = DateTime::createFromFormat($datetype . ' H:i:s', $match->Date . ' ' . $match->Time);
        if ($date) {
          $datestring = $date->format('D j/M Y, H\ui');
        }
      }
      else {
        $date = DateTime::createFromFormat($datetype, $match->Date);
        if ($date) {
          $datestring = $date->format('D j/M Y');
        }
      }
    }

    $row[] = $datestring;

    $output .= theme('table', array('header' => $header, 'rows' => array($row))) . "\n";
    if (variable_get('tabt_matches_get_results')) {
      $output .= '<div style="float: left; width: 50%;">' . "\n";
      $output .= '<h2>' . t('Hometeam') . '</h2>' . "\n";

      $header = array(array('style' => 'text-align: center; width: 20px;', 'data' => '#'), array('style' => 'text-align: center; width: 40px;', 'data' => t('Index')), t('Name'), array('style' => 'text-align: center; width: 20px;', 'data' => t('Rk.')), array('style' => 'text-align: center; width: 20px;', 'data' => t('Wins')));
      $rows = array();
      foreach ($match->HomeTeamMembers as $teammember) {
        $row = array(array('style' => 'text-align: center;', 'data' => check_plain($teammember->Id)), array('style' => 'text-align: center;', 'data' => check_plain($teammember->Index)));
        if (isset($teammember->Link)) {
          $row[] = l($teammember->Name, $teammember->Link);
        }
        else {
          $row[] = check_plain($teammember->Name);
        }
        array_push($row, array('style' => 'text-align: center;', 'data' => check_plain($teammember->Rank)), array('style' => 'text-align: center;', 'data' => check_plain($teammember->Wins)));
        $rows[] = $row;
      }
      if (isset($match->Doubles->Home)) {
        $row = array();
        $row[] = array('colspan' => '2', 'style' => 'text-align: center;', 'data' => t('Double'));
        if (isset($match->Doubles->Home->Players[0])) {
          if (isset($match->HomeTeamMembers[$match->Doubles->Home->Players[0] - 1]->Name)) {
            $player1 = check_plain($match->HomeTeamMembers[$match->Doubles->Home->Players[0] - 1]->Name);
          }
          else {
            $player1 = check_plain($match->Doubles->Home->Players[0]);
          }
          if (isset($match->Doubles->Home->Players[1])) {
            if (isset($match->HomeTeamMembers[$match->Doubles->Home->Players[1] - 1]->Name)) {
              $player2 = check_plain($match->HomeTeamMembers[$match->Doubles->Home->Players[1] - 1]->Name);
            }
            else {
              $player2 = check_plain($match->Doubles->Home->Players[1]);
            }
            $homedouble = check_plain($player1) . '<br />' . check_plain($player2);
          }
          else {
            $homedouble = check_plain($player1) . '<br />' . t('Unknown');
          }
        }
        else {
          $homedouble = t('Unknown');
        }
        array_push($row, $homedouble, '', array('style' => 'text-align: center;', 'data' => check_plain($match->Doubles->Home->Wins)));
        $rows[] = $row;
      }
      $output .= theme('table', array('header' => $header, 'rows' => $rows)) . "\n";
      $output .= '</div>' . "\n";

      $output .= '<div style="float: right; width: 50%;">' . "\n";
      $output .= '<h2>' . t('Awayteam') . '</h2>' . "\n";
      $rows = array();
      foreach ($match->AwayTeamMembers as $teammember) {
        $row = array(array('style' => 'text-align: center;', 'data' => check_plain($teammember->Id)), array('style' => 'text-align: center;', 'data' => check_plain($teammember->Index)));
        if (isset($teammember->Link)) {
          $row[] = array('style' => ($teammember->Wins == 'W-O' ? 'text-decoration: line-through;' : ''), 'data' => l($teammember->Name, $teammember->Link));
        }
        else {
          $row[] = array('style' => ($teammember->Wins == 'W-O' ? 'text-decoration: line-through;' : ''), 'data' => check_plain($teammember->Name));
        }
        array_push($row, array('style' => 'text-align: center;', 'data' => check_plain($teammember->Rank)), array('style' => 'text-align: center;', 'data' => check_plain($teammember->Wins)));
        $rows[] = $row;
      }
      if (isset($match->Doubles->Away)) {
        $row = array();
        $row[] = array('colspan' => '2', 'style' => 'text-align: center;', 'data' => t('Double'));
        if (isset($match->Doubles->Away->Players[0])) {
          if (isset($match->AwayTeamMembers[$match->Doubles->Away->Players[0] - 1]->Name)) {
            $player1 = check_plain($match->AwayTeamMembers[$match->Doubles->Away->Players[0] - 1]->Name);
          }
          else {
            $player1 = check_plain($match->Doubles->Away->Players[0]);
          }
          if (isset($match->Doubles->Away->Players[1])) {
            if (isset($match->AwayTeamMembers[$match->Doubles->Away->Players[1] - 1]->Name)) {
              $player2 = check_plain($match->AwayTeamMembers[$match->Doubles->Away->Players[1] - 1]->Name);
            }
            else {
              $player2 = check_plain($match->Doubles->Away->Players[1]);
            }
            $awaydouble = check_plain($player1) . '<br />' . check_plain($player2);
          }
          else {
            $awaydouble = check_plain($player1) . '<br />' . t('Unknown');
          }
        }
        else {
          $awaydouble = t('Unknown');
        }
        array_push($row, $awaydouble, '', array('style' => 'text-align: center;', 'data' => check_plain($match->Doubles->Away->Wins)));
        $rows[] = $row;
      }
      $output .= theme('table', array('header' => $header, 'rows' => $rows)) . "\n";
      $output .= '</div>' . "\n";

      $output .= '<div style="clear: both;">' . "\n";
      $output .= '<h2>' . t('Match List') . '</h2>' . "\n";
      $header = array(array('colspan' => 2, 'style' => 'text-align: center; width: 10%;', 'data' => '#'), array('colspan' => 2, 'style' => 'text-align: right; width: 50% - 52px;', 'data' => t('Hometeam')), array('colspan' => 2, 'style' => 'width: 50% - 53px;', 'data' => t('Awayteam')), array('style' => 'width: 5%; text-align: center;', 'data' => t('Score')));
      $rows = array();
      $setresults = (isset($match->Matches[0]->Sets) && variable_get('tabt_matches_show_sets'));
      if ($setresults) {
        $output .= '
        <script type="text/javascript">
        var showsets = true;
        function togglesets() {
        if (showsets == true) {
        showsets = false;
        document.getElementById(\'settoggle\').innerHTML = \'' . t('Show Sets') . '\';
      } else {
      showsets = true;
      document.getElementById(\'settoggle\').innerHTML = \'' . t('Hide Sets') . '\';
      }
      var els = getElsByClassName(\'set\');
      for (i in els) {
      if (showsets == true) {
      els[i].style.display = \'\';
      } else {
      els[i].style.display = \'none\';
      }
      }
      }

      function getElsByClassName(searchClass,node,tag){
      var classElements = new Array();
      if ( node == null )
      node = document;
      if ( tag == null )
      tag = \'*\';
      var els = node.getElementsByTagName(tag);
      var elsLen = els.length;
      var pattern = new RegExp("(^|\\s)"+searchClass+"(\\s|$)");
      for (i = 0, j = 0; i < elsLen; i++) {
      if ( pattern.test(els[i].className) ) {
      classElements[j] = els[i];
      j++;
      }
      }
      return classElements;
      }
      document.write(\'<a href="#" onclick="togglesets(); return false;" id="settoggle">' . t('Hide Sets') . '</a>\');
      </script>
      ' . "\n";
      }
      foreach ($match->Matches as $game) {
        if ($game->HomePlayer == 'Double') {
          $row = array(array('style' => 'width: 20px; text-align: center;', 'rowspan' => ($setresults ? '2' : '1'), 'data' => check_plain($game->Id)), array('style' => 'width: 30px; text-align: center;', 'rowspan' => ($setresults ? '2' : '1'), 'data' => t('Double')));
          if (isset($homedouble)) {
            $home = $homedouble;
          }
          else {
            $home = t('Double');
          }
          if (isset($awaydouble)) {
            $away = $awaydouble;
          }
          else {
            $away = t('Double');
          }
        }
        else {
          $row = array(array('style' => 'width: 20px; text-align: center;', 'rowspan' => ($setresults ? '2' : '1'), 'data' => check_plain($game->Id)), array('style' => 'width: 30px; text-align: center;', 'rowspan' => ($setresults ? '2' : '1'), 'data' => check_plain($game->HomePlayerId . ' - ' . $game->AwayPlayerId)));
          if (isset($match->HomeTeamMembers[$game->HomePlayerId - 1]->Name)) {
            $home = check_plain($match->HomeTeamMembers[$game->HomePlayerId - 1]->Name);
          }
          else {
            $home = check_plain($game->HomePlayer);
          }
          if (isset($match->AwayTeamMembers[$game->AwayPlayerId - 1]->Name)) {
            $away = check_plain($match->AwayTeamMembers[$game->AwayPlayerId - 1]->Name);
          }
          else {
            $away = check_plain($game->AwayPlayer);
          }
        }
        if ($game->HomeSets != 'W-O') {
          array_push($row, array('style' => ($game->HomeSets > $game->AwaySets ? 'font-weight: bold; width: 40%;' : '') . 'text-align: right;', 'data' => $home), array('style' => ($game->HomeSets > $game->AwaySets ? 'font-weight: bold; width: 20px;' : '') . 'text-align: right;', 'data' => check_plain($game->HomeSets)));
          array_push($row, array('style' => ($game->HomeSets < $game->AwaySets ? 'font-weight: bold; width: 20px;' : ''), 'data' => check_plain($game->AwaySets)), array('style' => ($game->HomeSets < $game->AwaySets ? 'font-weight: bold; width: 44%;' : ''), 'data' => $away));
        }
        else {
          if ($match->HomeTeamMembers[$game->HomePlayerId - 1]->Wins == 'W-O') {
            array_push($row, array('style' => 'text-decoration: line-through; text-align: right;', 'data' => $home), array('style' => 'text-align: right; width: 20px;', 'data' => 'W-O'), array('style' => 'font-weight: bold;', 'data' => ''), array('style' => 'font-weight: bold; width: 44%;', 'data' => $away));
          }
          else {
            array_push($row, array('style' => 'font-weight: bold; text-align: right;', 'data' => $home), array('style' => 'font-weight: bold; text-align: right;', 'data' => ''), array('style' => 'width: 20px;', 'data' => 'W-O'), array('style' => 'text-decoration: line-through;', 'data' => $away));
          }
        }
        $row[] = array('style' => 'text-align: center', 'rowspan' => ($setresults ? '2' : '1'), 'data' => check_plain($game->HomeScore . ' - ' . $game->AwayScore));
        $rows[] = $row;
        if ($setresults) {
          $row2 = array();
          foreach ($game->Sets as $set) {
            if (isset($set->HomeScore)) {
              if ($set->HomeScore > $set->AwayScore) {
                $row2[] = array('style' => 'width: 60px; text-align: center; border-top: 0px; border-bottom: 0px;', 'data' => '<strong>' . check_plain($set->HomeScore) . '</strong> - ' . check_plain($set->AwayScore));
              }
              else {
                $row2[] = array('style' => 'width: 60px; text-align: center; border-top: 0px; border-bottom: 0px;', 'data' => check_plain($set->HomeScore) . ' - <strong>' . check_plain($set->AwayScore) . '</strong>');
              }
            }
            else {
              $row2[] = array('style' => 'width: 60px; text-align: center; border-top: 0px; border-bottom: 0px;', 'data' => '&nbsp;');
            }

          }
          $table2 = theme('table', array('rows' => array(array('no_striping' => TRUE, 'style' => 'border: 0px;', 'data' => $row2)), 'attributes' => array('style' => 'width: auto; margin: 0; padding-bottom: 10spx; text-align: center;')));
          $rows[] = array('no_striping' => TRUE, 'class' => array(($game->Id % 2 == 1 ? 'odd' : 'even')), 'data' => array(array('class' => array('set'), 'style' => 'text-align: center; padding: 0%; padding-right: 4%;', 'colspan' => 4, 'data' => '<center>' . $table2 . '</center>')));
        }
      }

      $output .= theme('table', array('header' => $header, 'rows' => $rows)) . "\n";
      $output .= '</div>' . "\n";
    }
  }

  $output .= '<small>' . (t('Information obtained from !link', array('!link' => l('http://' . variable_get('tabt_site', 'competitie.vttl.be'), 'http://' . variable_get('tabt_site', 'competitie.vttl.be'))))) . '</small>' . "\n";

  if (variable_get('tabt_matches_reportview') && ($match->id || $match->MatchUniqueId)) {
    $output .= '<h2>' . t('Match Reports') . '</h2>' . "\n";
    $output .= views_embed_view(variable_get('tabt_matches_reportview'), 'block', ($match->id ? $match->id : $match->MatchUniqueId)) . "\n";
  }

  return $output;
}