<?php

/**
 * @file
 * Create and theme the rankingpage.
 */

/**
 * Create the rankingpage for a team.
 *
 * This page can be formatted with theme_tabt_ranking().
 * The rankingarray can be accessed through $ranking.
 *
 * @param team
 *   The team to get the ranking for.
 * @param season
 *   The season being viewed.
 */
function tabt_matches_ranking($team, $season = NULL) {
  // We only show the ranking for a valid team.
  if (!tabt_is_valid_team(drupal_strtoupper($team), $season)) {
    drupal_not_found();
    return;
  }

  // Get the teaminfo so we can get the division.
  $teaminfo = tabt_get_teaminfo($team, $season);

  if (!$teaminfo) {
    // If we get here, the API screwed up and we didn't get a valid
    // TeamEntry-object.
    drupal_not_found();
    return;
  }
  $season = tabt_process_seasonnumber($season);
  // Set the pagetitle and replace the tokens.
  $title = format_string(variable_get('tabt_matches_rankingpage_title', 'Ranking @club @team: @division - @season'),
      array('@club' => variable_get('tabt_club_name', 'Team'), '@team' => tabt_get_teamname($team, $season), '@division' => $teaminfo->DivisionName, '@season' => tabt_get_seasonname($season)));
  drupal_set_title($title);

  // Get the ranking.
  $ranking = tabt_matches_get_ranking($teaminfo);

  return array(
      '#theme'     => 'tabt_ranking',
      'team'       => $team,
      'ranking'    => $ranking,
      '#teaminfo'  => $teaminfo,
      '#ranking'   => $ranking,
      '#season' => $season
  );
}

/**
 * Theme the rankingpage.
 */
function theme_tabt_ranking($variables) {
  $teaminfo = $variables['teaminfo'];
  $ranking = $variables['ranking'];
  $output = '';

  if (isset($teaminfo->Alias)) {
    $teamseasons = tabt_get_seasons_teams($teaminfo->Alias);
    $output .= '<center>' . tabt_get_seasons_form($variables['season'], variable_get('tabt_matches_rankingpage', 'championship/ranking') . '/' . $teaminfo->Alias, $teamseasons) . '</center>';
  }

  $header = array('', '', array('data' => t('Matches'), 'colspan' => 4, 'style' => 'text-align: center'), '');
  $rows = array();
  $rows[] = array(array('header' => '', 'data' => t('Rank')), array('header' => '', 'data' => t('Team')), array('header' => '', 'data' => t('Played')), array('header' => '', 'data' => t('Won')), array('header' => '', 'data' => t('Lost')), array('header' => '', 'data' => t('Draw')), array('header' => '', 'data' => t('Points')));
  foreach ($ranking as $club) {
    $row = array(check_plain($club->Position), check_plain($club->Team), check_plain($club->GamesPlayed), check_plain($club->GamesWon), check_plain($club->GamesLost), check_plain($club->GamesDraw), check_plain($club->Points));
    if ($club->TeamClub == variable_get('tabt_club_id', 'Vl-B000') && drupal_strtoupper(drupal_substr($club->Team, -1)) == drupal_strtoupper($teaminfo->Team)) {
      $row = array('data' => $row, 'style' => 'font-weight:bold;');
    }
    $rows[] = $row;
  }
  $output .= theme('table', array('header' => $header, 'rows' => $rows));
  $output .= '<small>' . (t('Information obtained from !link', array('!link' => l('http://' . variable_get('tabt_site', 'competitie.vttl.be'), 'http://' . variable_get('tabt_site', 'competitie.vttl.be'))))) . '</small>' . "\n";

  return $output;
}