<?php
/**
 * @file
 * The load_results() function to load individual results.
 */

/**
 * Load the individual results and store them in the TabTMember-object.
 *
 * @param member
 *   The TabTMember-object
 * @param women
 *   Load women results.
 */
function _tabt_members_load_results($member, $women = FALSE) {
  $member->ResultsLoaded = FALSE;
  if (!$member->UniqueIndex || $member->UniqueIndex == '' || !variable_get('tabt_members_get_results'))
    return;
  if (!variable_get('tabt_caching') || !$data = tabt_cache_get('tabt_members_memberresults' . ($women ? 'wom' : '') . '_' . $member->UniqueIndex . '_' . $member->Season)) {
    // Load up the site with the individual results.
    $contents = file_get_contents('http://' . variable_get('tabt_site', 'competitie.vttl.be') . '/index.php?result=1&index=' . $member->UniqueIndex . '&menu=6&lang=en&season=' . $member->Season . ($women ? '&category=2' : ''));
    // The site uses a different encoding than we are using, so change it or
    // we lose names.
    $contents = iconv('Windows-1252', 'UTF-8', $contents);
    $lines = explode("\n", $contents);
    $currentdata = 'pic';
    $currentdata2 = '';
    $data = new stdClass();
    $breakfor = FALSE;
    foreach ($lines as $line) {
      if ($breakfor) {
        break;
      }
      switch ($currentdata) {
        case 'pic':
          // We first try to get the picture.
          if (strpos($line, '<td class="DBTable_first"><IMG alt="') !== FALSE) {
            if (preg_match('/\<td class="DBTable_first"><IMG alt="[^"]+" src="([^"]+)" border="0">/', $line, $matches)) {
              $data->Pic = 'http://' . variable_get('tabt_site', 'competitie.vttl.be') . $matches[1];
            }
            $currentdata = 'ranking';
          }
          break;
        case 'ranking':
          if (strpos($line, '<td class="DBTable_first">Ranking') !== FALSE) {
            $parts = explode('&nbsp;:&nbsp;', trim(strip_tags($line)));
            if (isset($parts[1])) {
              $data->Ranking = $parts[1];
            }
            $currentdata = 'start';
          }
          break;
        case 'start':
          // First we get the overview per rank.
          if (strpos($line, '</TR></TABLE>Summary per ranking') !== FALSE) {
            $currentdata = 'ranksum';
            $currentdata2 = 'start';
            $datalist = array();
            $dataentry = new stdClass();
          }
          break;
        case 'ranksum':
          if (strpos($line, '</TR></TABLE></TD><TD width=50% valign="top">Summary - Match') !== FALSE) {
            // We've reached the end. Store the info and move on to the
            // match-summary.
            $currentdata = 'matchsum';
            $currentdata2 = 'perc';
            $data->RankSum = $datalist;
            $datalist = array();
            $dataentry = new stdClass();
          }
          else {
            switch ($currentdata2) {
              case 'start':
                // First we get the rank.
                if (strpos($line, '<td class="DBTable_first">') !== FALSE) {
                  $dataentry->Rank = trim(strip_tags($line));
                  $currentdata2 = 'win';
                }
                break;
              case 'win':
                // Get the number of wins.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Win = trim(strip_tags($line));
                  $currentdata2 = 'lose';
                }
                break;
              case 'lose':
                // Then get the number of losses.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Lose = trim(strip_tags($line));
                  $currentdata2 = 'perc';
                }
                break;
              case 'perc':
                // And as last we get the percentage of wins.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $perc = explode(' ', trim(strip_tags($line)));
                  $dataentry->Perc = $perc[0];
                  // This is the last bit of info, so store it and get ready
                  // for the next rank.
                  $datalist[] = $dataentry;
                  $dataentry = new stdClass();
                  $currentdata2 = 'start';
                }
                break;
            }
          }
          break;
        case 'matchsum':
          if (strpos($line, '</TR></TABLE>Summary - Sets') !== FALSE) {
            // We've reached the end, so store the info and get ready for the
            // setsummary.
            $currentdata = 'setsum';
            $currentdata2 = 'perc';
            $data->MatchSum = $dataentry;
            $datalist = array();
            $dataentry = new stdClass();
          }
          else {
            switch ($currentdata2) {
              case 'perc':
                // We first get the percentage of wins.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $perc = explode(' ', trim(strip_tags($line)));
                  $dataentry->Perc = $perc[0];
                  $currentdata2 = 'play';
                }
                break;
              case 'play':
                // Next we get the number of matches played.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Play = trim(strip_tags($line));
                  $currentdata2 = 'win';
                }
                break;
              case 'win':
                // Get the number of wins.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Win = trim(strip_tags($line));
                  $currentdata2 = 'lose';
                }
                break;
              case 'lose':
                // Get the number of losses.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Lose = trim(strip_tags($line));
                  $currentdata2 = 'abs';
                }
                break;
              case 'abs':
                // Get the absolute points.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Abs = trim(strip_tags($line));
                  $currentdata2 = 'rel';
                }
                break;
              case 'rel':
                // Get the relative points.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Rel = trim(strip_tags($line));
                  $currentdata2 = 'elo';
                }
                break;
              case 'elo':
                // Finally get the ELO-points.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Elo = trim(strip_tags($line));
                  $currentdata2 = 'end';
                }
                break;
            }
          }
          break;
        case 'setsum':
          if (strpos($line, '</TR></TABLE>Distribution of scores (Sets):') !== FALSE) {
            // We've reached the end, so store the info and get ready for
            // setdistribution.
            $currentdata = 'setdistrib';
            $currentdata2 = 'start';
            $data->SetSum = $dataentry;
            $datalist = array();
            $dataentry = new stdClass();
          }
          else {
            switch ($currentdata2) {
              case 'perc':
                // First we get the percentage of wins.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $perc = explode(' ', trim(strip_tags($line)));
                  $dataentry->Perc = $perc[0];
                  $currentdata2 = 'play';
                }
                break;
              case 'play':
                // Get the number of sets played.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Play = trim(strip_tags($line));
                  $currentdata2 = 'win';
                }
                break;
              case 'win':
                // Get the number of wins.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Win = trim(strip_tags($line));
                  $currentdata2 = 'lose';
                }
                break;
              case 'lose':
                // Get the number of losses.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Lose = trim(strip_tags($line));
                  $currentdata2 = 'avg';
                }
                break;
              case 'avg':
                // Get the average number of sets per match.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Avg = trim(strip_tags($line));
                  $currentdata2 = 'end';
                }
                break;
            }
          }
          break;
        case 'setdistrib':
          if (strpos($line, '</TR></TABLE>Last set results:') !== FALSE) {
            // We've reached the end, so store the info and move on to the
            // last-set results.
            $currentdata = 'bellesum';
            $currentdata2 = 'start';
            $data->SetDistrib = $datalist;
            $datalist = array();
            $dataentry = new stdClass();
          }
          elseif (strpos($line, '</script>ELO points evolution') !== FALSE) {
            // We've reached the end, but we seem to have reached ELO-points
            // right away.
            $currentdata = 'elo';
            $currentdata2 = 'start';
            $data->SetDistrib = $datalist;
            $datalist = array();
            $dataentry = new stdClass();
          }
          elseif (strpos($line, '</TR></TABLE>Match list') !== FALSE) {
            // We've reached the end, but we seem to have reached ELO-points
            // right away.
            $currentdata = 'matches';
            $currentdata2 = 'start';
            $data->SetDistrib = $datalist;
            $datalist = array();
            $dataentry = new stdClass();
            $columns = array();
          }
          else {
            switch ($currentdata2) {
              case 'start':
                // Get the setscore.
                if (strpos($line, '<td class="DBTable_first">') !== FALSE) {
                  $score = explode('&nbsp;-&nbsp;', trim(strip_tags($line)));
                  $dataentry->Win = $score[0];
                  $dataentry->Lose = $score[1];
                  $currentdata2 = 'number';
                }
                break;
              case 'number':
                // Get the amount.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Number = trim(strip_tags($line));
                  $datalist[] = $dataentry;
                  $dataentry = new stdClass();
                  $currentdata2 = 'start';
                }
                break;
            }
          }
          break;
        case 'bellesum':
          // We don't always get this information. Only if the player already
          // had a match with 5 sets.
          if (strpos($line, '</script>ELO points evolution') !== FALSE) {
            // We've reached the end, so store the info and move on to
            // ELO Points.
            $currentdata = 'elo';
            $currentdata2 = 'start';
            $data->BelleSum = $dataentry;
            $datalist = array();
            $dataentry = new stdClass();
          }
          elseif (strpos($line, '</TR></TABLE>Match list') !== FALSE) {
            // We've reached the end, so store the info and move on to the
            // matchlist.
            $currentdata = 'matches';
            $currentdata2 = 'start';
            $data->BelleSum = $dataentry;
            $datalist = array();
            $dataentry = new stdClass();
            $columns = array();
          }
          else {
            switch ($currentdata2) {
              case 'start':
                // We first get the amount.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Play = trim(strip_tags($line));
                  $currentdata2 = 'playperc';
                }
                break;
              case 'playperc':
                // Get the percentage in relation to amount of sets.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $perc = explode(' ', trim(strip_tags($line)));
                  $dataentry->PlayPerc = $perc[0];
                  $currentdata2 = 'win';
                }
                break;
              case 'win':
                // Get the number of wins.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Win = trim(strip_tags($line));
                  $currentdata2 = 'winperc';
                }
                break;
              case 'winperc':
                // Get the percentage of wins in relation to amount of
                // 5 set-matches.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $perc = explode(' ', trim(strip_tags($line)));
                  $dataentry->WinPerc = $perc[0];
                  $currentdata2 = 'lose';
                }
                break;
              case 'lose':
                // Get the number of losses.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Lose = trim(strip_tags($line));
                  $currentdata2 = 'loseperc';
                }
                break;
              case 'loseperc':
                // Get the percentage of losses in relation to amount of
                // 5 set-matches.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $perc = explode(' ', trim(strip_tags($line)));
                  $dataentry->LosePerc = $perc[0];
                  $currentdata2 = 'end';
                }
                break;
            }
          }
          break;
        case 'elo':
          if (strpos($line, '</TR></TABLE>Match list') !== FALSE) {
            // We've reached the end, so store the info and move on to the
            // matchlist.
            $currentdata = 'matches';
            $currentdata2 = 'start';
            $data->Elo = $dataentry;
            $datalist = array();
            $dataentry = new stdClass();
            $columns = array();
          }
          else {
            switch ($currentdata2) {
              case 'start':
                $currentdata3 = 'start';
                // Eeverything is on one line here...
                if (strpos($line, '<td class="DBTable_first" valign="top"><table width="100%">') !== FALSE) {
                  // Split it into rows.
                  $parts = explode('<tr>', $line);
                  $breakfor2 = FALSE;
                  foreach ($parts as $part) {
                    if ($breakfor2) {
                      break;
                    }
                    switch ($currentdata3) {
                      case 'start':
                        // First we search for the season start.
                        if (strpos($part, 'Season start') !== FALSE) {
                          $parts2 = explode('</td><td>', $part);
                          $dataentry->Start = trim(strip_tags($parts2[1]));
                          $currentdata3 = 'min';
                        }
                        break;
                      case 'min':
                        // Then the minimum.
                        if (strpos($part, 'Minimum on') !== FALSE) {
                          $parts2 = explode('</td><td>', $part);
                          $parts3 = explode(' ', trim(strip_tags($parts2[0])));
                          $dataentry->MinDate = $parts3[2];
                          $dataentry->Min = trim(strip_tags($parts2[1]));
                          $currentdata3 = 'max';
                        }
                        break;
                      case 'max':
                        // Then the maximum.
                        if (strpos($part, 'Maximum on') !== FALSE) {
                          $parts2 = explode('</td><td>', $part);
                          $parts3 = explode(' ', trim(strip_tags($parts2[0])));
                          $dataentry->MaxDate = $parts3[2];
                          $dataentry->Max = trim(strip_tags($parts2[1]));
                          $currentdata3 = 'current';
                        }
                        break;
                      case 'current':
                        // Finally, the current amount.
                        if (strpos($part, 'Today') !== FALSE) {
                          $parts2 = explode('</td><td>', $part);
                          $dataentry->Current = trim(strip_tags($parts2[1]));
                          $currentdata3 = 'end';
                          $breakfor2 = TRUE;
                        }
                        break;
                    }
                  }
                  $currentdata2 = 'link';
                }
                break;
              case 'link';
              // Let's also try to get the image.
              if (strpos($line, '<IMG id="elo_graph" src="') !== FALSE) {
                if (preg_match('/\<IMG id="elo_graph" src="([^"]+)" border="0" align="absmiddle">/', $line, $matches)) {
                  $dataentry->Link = 'http://' . variable_get('tabt_site', 'competitie.vttl.be') . '/' . $matches[1];
                }
                $currentdata2 = 'end';
              }
              break;
            }
          }
          break;
        case 'matches':
          if (strpos($line, '<TR VALIGN=top>') !== FALSE) {
            // We've reached the end, so store it and stop processing.
            $currentdata = 'end';
            $data->Matches = $datalist;
            $datalist = array();
            $dataentry = new stdClass();
            $breakfor = TRUE;
          }
          elseif (strpos($line, '<tr class="DBTable">') !== FALSE) {
            // We've reached the end, so store it and stop processing.
            if ($currentdata2 != 'start') {
              $currentdata2 = 'start';
              $datalist[] = $dataentry;
              $dataentry = new stdClass();
            }
          }
          else {
            switch ($currentdata2) {
              case 'start':
                // First we get the date.
                if (strpos($line, '<td class="DBTable_first">') !== FALSE) {
                  if (isset($columns['date']) && $columns['date']) {
                    $dataentry->Date = trim(strip_tags($line));
                    $currentdata2 = 'type';
                  }
                  else {
                    $dataentry->Type = trim(strip_tags($line));
                    if ($dataentry->Type == '') {
                      $dataentry->Type = 'Champ.';
                    }
                    $currentdata2 = 'matchid';
                  }
                }
                elseif (strpos($line, '<th class=DBTable>Date</th>') !== FALSE) {
                  $columns['date'] = TRUE;
                }
                elseif (strpos($line, '<th class=DBTable>ELO<br>Opp.</th>') !== FALSE) {
                  $columns['elo'] = TRUE;
                }
                break;
              case 'type':
                // Get the type of match.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Type = trim(strip_tags($line));
                  if ($dataentry->Type == '') {
                    $dataentry->Type = 'Champ.';
                  }
                  $currentdata2 = 'matchid';
                }
                break;
              case 'matchid':
                // Get the MatchID and the link to the match.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Matchid = trim(strip_tags($line));
                  if (preg_match('/\<A class=DBTable href="([^"]+)">/', $line, $matches)) {
                    $dataentry->MatchLink = 'http://' . variable_get('tabt_site', 'competitie.vttl.be') . '/index.php' . $matches[1];
                  }
                  $currentdata2 = 'team';
                }
                break;
              case 'team':
                // Get the team or series.
                // Also try to get the link to the team if it's available.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Team = trim(strip_tags($line));
                  if (preg_match("/\<A class=DBTable href='([^']+)'>/", $line, $matches)) {
                    $dataentry->TeamLink = 'http://' . variable_get('tabt_site', 'competitie.vttl.be') . $matches[1] . '&season=' . $member->Season;
                  }
                  $currentdata2 = 'oppteam';
                }
                break;
              case 'oppteam':
                // Get the opposing team.
                // Also try to get the teamlink.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->OppTeam = trim(strip_tags($line));
                  if (preg_match("/\<A class=DBTable href='([^']+)'>/", $line, $matches)) {
                    $dataentry->OppTeamLink = 'http://' . variable_get('tabt_site', 'competitie.vttl.be') . $matches[1] . '&season=' . $member->Season;
                  }
                  $currentdata2 = 'opp';
                }
                break;
              case 'opp':
                // Get the opponent and their link.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Opp = ucwords(drupal_strtolower(trim(strip_tags($line))));
                  if (preg_match("/\<A class=DBTable href='([^']+)'>/", $line, $matches)) {
                    $dataentry->OppLink = 'http://' . variable_get('tabt_site', 'competitie.vttl.be') . $matches[1] . '&season=' . $member->Season;
                  }
                  $currentdata2 = 'opprank';
                }
                break;
              case 'opprank':
                // Get the opponents rank.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->OppRank = trim(strip_tags($line));
                  if (isset($columns['elo']) && $columns['elo']) {
                    $currentdata2 = 'oppelo';
                  }
                  else {
                    $currentdata2 = 'score';
                  }
                }
                break;
              case 'oppelo':
                // Get the opponents ELO points.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->OppElo = trim(strip_tags($line));
                  $currentdata2 = 'score';
                }
                break;
              case 'score':
                // Get the matchscore.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $score = explode('&nbsp;-&nbsp;', trim(strip_tags($line)));
                  $dataentry->Win = $score[0];
                  $dataentry->Lose = $score[1];
                  $currentdata2 = 'elo';
                }
                break;
              case 'elo':
                // Get the players elo-points before the match.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->Elo = trim(strip_tags($line));
                  $currentdata2 = 'elodiff';
                }
                break;
              case 'elodiff':
                // Finally, get the ELO-points that were added/removed.
                if (strpos($line, '<td class=DBTable>') !== FALSE) {
                  $dataentry->EloDiff = trim(strip_tags($line));
                  // This is the last part, so store the data and get ready
                  // for another match.
                  $datalist[] = $dataentry;
                  $dataentry = new stdClass();
                  $currentdata2 = 'start';
                }
                break;
            }
          }
          break;
      }
    }
    if (isset($data->Ranking)) {
      if (tabt_is_current_season($member->Season)) {
        tabt_cache_set('tabt_members_memberresults' . ($women ? 'wom' : '') . '_' . $member->UniqueIndex . '_' . $member->Season, $data, 1 * 60 * 60 * 24);
      }
      else {
        tabt_cache_set('tabt_members_memberresults' . ($women ? 'wom' : '') . '_' . $member->UniqueIndex . '_' . $member->Season, $data, 6 * 30 * 60 * 60 * 24);
      }
      $member->ResultsLoaded = TRUE;
    }
  }
  if ($data === FALSE || !isset($data->Ranking)) {
    $olddata = tabt_cache_get('tabt_members_memberresults' . ($women ? 'wom' : '') . '_' . $member->UniqueIndex . '_' . $member->Season, TRUE);
    if ($olddata !== FALSE && isset($oldata->Ranking)) {
      $data = $olddata;
    }
  }
  if ($women) {
    $member->WomenResults = $data;
  }
  else {
    $member->Results = $data;
  }
}